"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@nestjs/common");
const role_reflection_token_1 = require("./role-reflection-token");
function createRolesGuard(getRole) {
    var _a;
    return _a = class RolesGuard {
            constructor(reflector) {
                this.reflector = reflector;
            }
            canActivate(context) {
                const requiredRoles = this.reflector.getAllAndOverride(role_reflection_token_1.roleReflectionToken, [context.getHandler(), context.getClass()]);
                // roles are not set - handler is allowed for all
                if (!requiredRoles) {
                    return true;
                }
                const role = getRole(context);
                // handler is allowed only for not authorized
                if (requiredRoles[0] === false) {
                    // but there is some role
                    if (role) {
                        throw new common_1.ForbiddenException();
                    }
                    return true;
                }
                // handler is allowed for any authorized
                if (requiredRoles[0] === true) {
                    // but there is not any role
                    if (role) {
                        throw new common_1.UnauthorizedException();
                    }
                    return true;
                }
                // handler is allowed for certain roles
                // there is no any role
                if (!role) {
                    throw new common_1.UnauthorizedException();
                }
                // role is not one of requireds
                if (!requiredRoles.includes(role)) {
                    throw new common_1.ForbiddenException();
                }
                return true;
            }
        },
        _a.Params = (...allowedRoles) => common_1.SetMetadata(role_reflection_token_1.roleReflectionToken, allowedRoles),
        _a;
}
exports.createRolesGuard = createRolesGuard;
//# sourceMappingURL=index.js.map